@@ -43,6 +43,7 @@ datasummary_extract <- function(tab,
 
   colnames(main) <- as.vector(mat[idx, ])
 
+
   # remove NAs, but not in stub or header
   for (i in (stub_width + 1):ncol(main)) {
     main[, i] <- trimws(main[, i])
@@ -53,6 +54,12 @@ datasummary_extract <- function(tab,
   # stub_width attribute before return
   attr(main, 'stub_width') <- stub_width
 
+  # escape latex column names
+  if (settings_equal("escape", TRUE) &&
+      settings_equal("output_format", c("latex", "latex_tabular", "html"))) {
+    colnames(main) <- escape_string(colnames(main))
+  }
+
   # 1 header level means colnames are sufficient. return output immediately.
   # this needs to go before definition of header_nocolnames
   if (nrow(header) == 1) {
@@ -104,6 +111,7 @@ datasummary_extract <- function(tab,
   # attributes
   attr(main, 'header_sparse_flat') <- header_sparse_flat
 
+
   # return
   return(main)
 
