@@ -355,7 +355,7 @@ datasummary_skim_categorical <- function(
   f <- All(dat_new, numeric = FALSE, factor = TRUE, logical = TRUE, character = TRUE) ~
        (N = 1) * Format() + (`%` = Percent()) * Format(pctformat())
 
-  out <- datasummary(
+  datasummary(
     formula = f,
     data = dat_new,
     output = output,
@@ -363,6 +363,4 @@ datasummary_skim_categorical <- function(
     align = align,
     notes = notes)
 
-  return(out)
-
 }
